run.peaks, extracts all peaks that are
large in all samples, and writes the results to a file.
run.strong.peaks(cor.thresh = 0.8, isotope.dist = 7, pre.align = FALSE, align.method = c("PL", "spline", "affine", "none"), align.fcn = NA, root.dir = ".", lrg.dir, lrg.file = "lrg_peaks.RData", overwrite = FALSE, use.par.file = FALSE, par.file = "parameters.RData")FALSE, or a numeric vector of shifts to apply to spectra, or a three-component list (of the form described in the Note section below) to be used before identifying peaks from different spectraalign.method; see belowpaste(root.dir, "/Large_Peaks", sep = "")TRUE, then parameters are read from par.file in directory root.dirrun.lrg.peaks, locates
peaks which appear in all samples, and overwrites the file lrg.file in
lrg.dir. The resulting file contains variables
amps |
| data frame of amplitudes of non-isotope peaks that occur in all samples |
centers |
| data frame of centers of non-isotope peaks that occur in all samples |
lrg.peaks |
the data frame of significant peaks created by run.lrg.peaks |
run.cluster.matrix.
Barkauskas, D.A. et al. (2009b) Analysis of MALDI FT-ICR mass spectrometry data: A time series approach. Analytica Chimica Acta, 648:2, 207--214.
Barkauskas, D.A. et al. (2009c) Detecting glycan cancer biomarkers in serum samples using MALDI FT-ICR mass spectrometry data. Bioinformatics, 25:2, 251--257.
Zhang, L.-K. et al. (2005) Accurate mass measurements by Fourier transform mass spectrometry. Mass Spectrom Rev, 24:2, 286--309.
run.lrg.peaks, run.cluster.matrix,
interpSpline